#include <stdio.h>
#include <stdlib.h>

#include "vektor-zeichen.h"

// Unser Vektorfont-Objekt
vecfont_t vecfont;

// Einige Hilfsvariablen
static int char_pending;
static int px, py;
static int skip, start;

// Implementierung von VF_NOTIFY_CHAR.
// Wir fassen jedes Zeichen in einer eigene SVG-Gruppe zusammen
// und stellen einen kleinen Kommentar vor jede Gruppe
void notify_char (vecfont_t * vf, char c)
{
    // Evtl. offene Zeichen schliessen
    if (char_pending)
        printf ("'/></g>\n");
        
    // Nur fr Zeichen != '\0' und != ' ' muss eine Gruppe erzeugt werden
    // da nur dann Pixel ausgegeben werden
    if ((char_pending = c && c != ' '))
        printf ("    <!-- \"%c\" * %d --><g transform='translate(%d,%d)'><path d='",
            c, vf->zoom, px = vf->p.x, py = vf->p.y);
}

// Callback: Der Strahl bzw. die Pixelposition macht einen Sprung
// Dieser Callback tut nichts ausser zu merken, da ein Sprung 
// stattgefunden hat.
static void beam_skip (void)
{
    skip = 1;
}

// Callback: Ein Pixel wird gesetzt
static void beam_xy (vf_uint_t x, vf_uint_t y)
{
    if (skip && start)
        // Bei 2 Sprngen in Folge wurde nur 1 einzelner Pixel ausgegeben.
        // Um ihn zu sehen mssen wir einen kleinen Strich machen. 
        // Der Pixel selbst entsteht dann durch Zusammenspiel der Attribute
        // stroke-linecap und stroke-width
        printf ("h0.01 M%d,%d ", x-px, y-py);
    else if (skip)
        // Ein Skip setzt die Koordinaten neu: MoveTo
        printf ("M%d,%d ", x-px, y-py);
    else
        // Kein Skip: LineTo
        printf ("L%d,%d ", x-px, y-py);
        
    start = skip;    
    skip  = 0;
}

int main (int argc, char *argv[])
{
    vecfont_t * vf = &vecfont;

    // Callbacks initialisieren
    vf->beam_skip = beam_skip;
    vf->beam_xy   = beam_xy;
    
    // Proportionalschrift
    vf->proportional = 1;
    
    // Text der Kommandozeile entnehmen
    if (argc != 2)
    {
        fprintf (stderr, "\nUsage: %s \"some text\"\n\n", argv[0]);
        exit (1);
    }
    vf->text = argv[1];
    
    // Startposition am oberen, linken Bildrand
    vf->start.x = 10;
    vf->start.y = 300;
    
    // Kopf der SVG-Datei
    printf ("<?xml version='1.0' encoding='UTF-8' standalone='no' ?>\n"
            "<svg\n"
            "    xmlns='http://www.w3.org/2000/svg'\n"
            "    xmlns:xlink='http://www.w3.org/1999/xlink'\n"
            "    viewBox='0 -900 600 250'\n"
            "    width='600'\n"
            "    height='250'\n"
            "    version='1.1'>\n");
    
    // Stil fr die Linien unserer Zeichen
    printf ("<style type='text/css'>\n"
            ".letter { fill:none; "
                      "stroke:#40f; "
                      "stroke-width:1; "
                      "stroke-linecap:square; "
                      "stroke-linejoin:round; "
                      "stroke-opacity:0.6; "
                      "\n}");
    printf ("</style>\n");
    
    // Diese Gruppe umpasst alles. Wir vergrern *3 und skalieren y mit -1
    // um die Spiegelung an der x-Achse zu erreichen (ansonsten steht alles auf
    // dem Kopf, weil das SVG-Koordinatensystem den Ursprung oben links hat)
    printf ("<g transform='scale(3,-3)' class='letter' >\n");
    
    // Wir zeichenen den Text in 3 Zoom-Stufen von 1 bis 3
    for (vf->zoom = 1; vf->zoom <= 3; vf->zoom++)
    {
        // Y-Koordinate vermindern, damit sich die Texte der
        // einzelnen Zoom-Stufen nicht berpinseln
        vf->start.y -= 10 * vf->zoom;
        
        // Bei jedem Aufruf wird ein Pixel gesetzt bis der Text fertig
        // ausgegeben ist. Zustzlich kann die x/y-Position einen Sprung machen.
        while (!vecfont_draw_letters (vf));
    }
    
    // Evtl. offene Zeichen schliessen
    if (char_pending)
        printf ("'/> </g>\n");
    
    printf ("</g>\n");
    printf ("</svg>\n");
    
    // Fertig!
    return 0;
}
