#include <stdio.h>
#include <stdlib.h>

#include "vektor-zeichen.h"

// Ein Array von 256 x 256 Pixeln fr eine PBM-Grafik. 
// Siehe http://de.wikipedia.org/wiki/Portable_Bitmap
unsigned char PBM[256][256];

// Unser Vektorfont-Objekt
vecfont_t vecfont;

// Callback: Der Strahl bzw. die Pixelposition mach einen Sprung
// Dieser Callback tut nichts, da wir nicht mit einem Plotter zeichenen
// oder auf eine Rhre.
static void beam_skip (void)
{
}

// Callback: Ein Pixel wird gesetzt
static void beam_xy (vf_uint_t x, vf_uint_t y)
{
    PBM[x & 255][y & 255] = 1;
}

int main (int argc, char *argv[])
{
    vecfont_t * vf = &vecfont;

    // Callbacks initialisieren
    vf->beam_skip = beam_skip;
    vf->beam_xy   = beam_xy;
    
    // Proportionalschrift
    vf->proportional = 1;
    
    // Text der Kommandozeile entnehmen
    if (argc != 2)
    {
        fprintf (stderr, "\nUsage: %s \"some text\"\n\n", argv[0]);
        exit (1);
    }
    vf->text = argv[1];
    
    // Startposition am oberen, linken Bildrand
    vf->start.x = 10;
    vf->start.y = 255;
    
    // Wir zeichenen den Text in 5 Zoom-Stufen von 1 bis 5
    for (vf->zoom = 1; vf->zoom <= 5; vf->zoom++)
    {
        // Y-Koordinate vermindern, damit sich die Texte der
        // einzelnen Zoom-Stufen nicht berpinseln
        vf->start.y -= 10 * vf->zoom;
        
        // Bei jedem Aufruf wird ein Pixel gesetzt bis der Text fertig
        // ausgegeben ist. Zustzlich kann die x/y-Position einen Sprung machen.
        while (!vecfont_draw_letters (vf));
    }
    
    // Text aus PBM[] im PBM-Format auf stdout ausgeben
    printf ("P1\n256 256\n# \"%s\" in 5 Zoom-Stufen", vf->text);
    for (int y = 0; y < 256; y++)
    {
        for (int x = 0; x < 256; x++)
            putc ('0' + PBM[x][255-y], stdout);
        
        fputs ("\n", stdout);
    }
    
    // Fertig!
    return 0;
}
